#ifndef _BATCHED_BLAS_dgemm_H_
#define _BATCHED_BLAS_dgemm_H_

#include "batched_blas_common.h"

void blas_srotg_batchf(const int group_size,float ** a,float ** b,float ** c,float ** s,int *info);
void blas_drotg_batchf(const int group_size,double ** a,double ** b,double ** c,double ** s,int *info);
void blas_srotmg_batchf(const int group_size,float ** d1,float ** d2,float ** x1,const float* y1,float ** param,int *info);
void blas_drotmg_batchf(const int group_size,double ** d1,double ** d2,double ** x1,const double* y1,double ** param,int *info);
void blas_srot_batchf(const int group_size,const int n,float ** x,const int incx,float ** y,const int incy,const float c1,const float s1,int *info);
void blas_drot_batchf(const int group_size,const int n,double ** x,const int incx,double ** y,const int incy,const double c1,const double s1,int *info);
void blas_srotm_batchf(const int group_size,const int n,float ** x,const int incx,float ** y,const int incy,const float ** param,int *info);
void blas_drotm_batchf(const int group_size,const int n,double ** x,const int incx,double ** y,const int incy,const double ** param,int *info);
void blas_sswap_batchf(const int group_size,const int n,float ** x,const int incx,float ** y,const int incy,int *info);
void blas_dswap_batchf(const int group_size,const int n,double ** x,const int incx,double ** y,const int incy,int *info);
void blas_cswap_batchf(const int group_size,const int n,bblas_complex32_t ** x,const int incx,bblas_complex32_t ** y,const int incy,int *info);
void blas_zswap_batchf(const int group_size,const int n,bblas_complex64_t ** x,const int incx,bblas_complex64_t ** y,const int incy,int *info);
void blas_sscal_batchf(const int group_size,const int n,const float a1,float ** x,const int incx,int *info);
void blas_dscal_batchf(const int group_size,const int n,const double a1,double ** x,const int incx,int *info);
void blas_cscal_batchf(const int group_size,const int n,const bblas_complex32_t * a,bblas_complex32_t ** x,const int incx,int *info);
void blas_zscal_batchf(const int group_size,const int n,const bblas_complex64_t * a,bblas_complex64_t ** x,const int incx,int *info);
void blas_csscal_batchf(const int group_size,const int n,const float a1,bblas_complex32_t ** x,const int incx,int *info);
void blas_zdscal_batchf(const int group_size,const int n,const double a1,bblas_complex64_t ** x,const int incx,int *info);
void blas_scopy_batchf(const int group_size,const int n,const float ** x,const int incx,float ** y,const int incy,int *info);
void blas_dcopy_batchf(const int group_size,const int n,const double ** x,const int incx,double ** y,const int incy,int *info);
void blas_ccopy_batchf(const int group_size,const int n,const bblas_complex32_t ** x,const int incx,bblas_complex32_t ** y,const int incy,int *info);
void blas_zcopy_batchf(const int group_size,const int n,const bblas_complex64_t ** x,const int incx,bblas_complex64_t ** y,const int incy,int *info);
void blas_saxpy_batchf(const int group_size,const int n,const float a1,const float ** x,const int incx,float ** y,const int incy,int *info);
void blas_daxpy_batchf(const int group_size,const int n,const double a1,const double ** x,const int incx,double ** y,const int incy,int *info);
void blas_caxpy_batchf(const int group_size,const int n,const bblas_complex32_t  a1,const bblas_complex32_t ** x,const int incx,bblas_complex32_t ** y,const int incy,int *info);
void blas_zaxpy_batchf(const int group_size,const int n,const bblas_complex64_t  a1,const bblas_complex64_t ** x,const int incx,bblas_complex64_t ** y,const int incy,int *info);
void blas_sdot_batchf(const int group_size,const int n,const float ** x,const int incx,const float ** y,const int incy,float* ret_cblas_sdot,int *info);
void blas_ddot_batchf(const int group_size,const int n,const double ** x,const int incx,const double ** y,const int incy,double* ret_cblas_ddot,int *info);
void blas_dsdot_batchf(const int group_size,const int n,const float ** x,const int incx,const float ** y,const int incy,double* ret_cblas_dsdot,int *info);
void blas_cdotu_batchf(const int group_size,const int n,const bblas_complex32_t ** x,const int incx,const bblas_complex32_t ** y,const int incy,bblas_complex32_t ** dotu,int *info);
void blas_zdotu_batchf(const int group_size,const int n,const bblas_complex64_t ** x,const int incx,const bblas_complex64_t ** y,const int incy,bblas_complex64_t ** dotu,int *info);
void blas_cdotc_batchf(const int group_size,const int n,const bblas_complex32_t ** x,const int incx,const bblas_complex32_t ** y,const int incy,bblas_complex32_t ** dotc,int *info);
void blas_zdotc_batchf(const int group_size,const int n,const bblas_complex64_t ** x,const int incx,const bblas_complex64_t ** y,const int incy,bblas_complex64_t ** dotc,int *info);
void blas_sdsdot_batchf(const int group_size,const int n,const float sb,const float ** sx,const int incx,const float ** sy,const int incy,float* ret_cblas_sdsdot,int *info);
void blas_snrm2_batchf(const int group_size,const int n,const float ** x,const int incx,float* ret_cblas_snrm2,int *info);
void blas_dnrm2_batchf(const int group_size,const int n,const double ** x,const int incx,double* ret_cblas_dnrm2,int *info);
void blas_scnrm2_batchf(const int group_size,const int n,const bblas_complex32_t ** x,const int incx,float* ret_cblas_scnrm2,int *info);
void blas_dznrm2_batchf(const int group_size,const int n,const bblas_complex64_t ** x,const int incx,double* ret_cblas_dznrm2,int *info);
void blas_sasum_batchf(const int group_size,const int n,const float ** x,const int incx,float* ret_cblas_sasum,int *info);
void blas_dasum_batchf(const int group_size,const int n,const double ** x,const int incx,double* ret_cblas_dasum,int *info);
void blas_scasum_batchf(const int group_size,const int n,const bblas_complex32_t ** x,const int incx,float* ret_cblas_scasum,int *info);
void blas_dzasum_batchf(const int group_size,const int n,const bblas_complex64_t ** x,const int incx,double* ret_cblas_dzasum,int *info);
void blas_isamax_batchf(const int group_size,const int n,const float ** x,const int incx,int* ret_cblas_isamax,int *info);
void blas_idamax_batchf(const int group_size,const int n,const double ** x,const int incx,int* ret_cblas_idamax,int *info);
void blas_icamax_batchf(const int group_size,const int n,const bblas_complex32_t ** x,const int incx,int* ret_cblas_icamax,int *info);
void blas_izamax_batchf(const int group_size,const int n,const bblas_complex64_t ** x,const int incx,int* ret_cblas_izamax,int *info);
void blas_sgemv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t transa,const int m,const int n,const float alpha,const float ** a,const int lda,const float ** x,const int incx,const float beta,float ** y,const int incy,int *info);
void blas_dgemv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t transa,const int m,const int n,const double alpha,const double ** a,const int lda,const double ** x,const int incx,const double beta,double ** y,const int incy,int *info);
void blas_cgemv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t transa,const int m,const int n,const bblas_complex32_t  alpha,const bblas_complex32_t ** a,const int lda,const bblas_complex32_t ** x,const int incx,const bblas_complex32_t  beta,bblas_complex32_t ** y,const int incy,int *info);
void blas_zgemv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t transa,const int m,const int n,const bblas_complex64_t  alpha,const bblas_complex64_t ** a,const int lda,const bblas_complex64_t ** x,const int incx,const bblas_complex64_t  beta,bblas_complex64_t ** y,const int incy,int *info);
void blas_sgbmv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t trans,const int m,const int n,const int kl,const int ku,const float alpha,const float ** a,const int lda,const float ** x,const int incx,const float beta,float ** y,const int incy,int *info);
void blas_dgbmv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t trans,const int m,const int n,const int kl,const int ku,const double alpha,const double ** a,const int lda,const double ** x,const int incx,const double beta,double ** y,const int incy,int *info);
void blas_cgbmv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t trans,const int m,const int n,const int kl,const int ku,const bblas_complex32_t  alpha,const bblas_complex32_t ** a,const int lda,const bblas_complex32_t ** x,const int incx,const bblas_complex32_t  beta,bblas_complex32_t ** y,const int incy,int *info);
void blas_zgbmv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t trans,const int m,const int n,const int kl,const int ku,const bblas_complex64_t  alpha,const bblas_complex64_t ** a,const int lda,const bblas_complex64_t ** x,const int incx,const bblas_complex64_t  beta,bblas_complex64_t ** y,const int incy,int *info);
void blas_chemv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const int n,const bblas_complex32_t  alpha,const bblas_complex32_t ** a,const int lda,const bblas_complex32_t ** x,const int incx,const bblas_complex32_t  beta,bblas_complex32_t ** y,const int incy,int *info);
void blas_zhemv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const int n,const bblas_complex64_t  alpha,const bblas_complex64_t ** a,const int lda,const bblas_complex64_t ** x,const int incx,const bblas_complex64_t  beta,bblas_complex64_t ** y,const int incy,int *info);
void blas_chbmv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const int n,const int k,const bblas_complex32_t  alpha,const bblas_complex32_t ** a,const int lda,const bblas_complex32_t ** x,const int incx,const bblas_complex32_t  beta,bblas_complex32_t ** y,const int incy,int *info);
void blas_zhbmv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const int n,const int k,const bblas_complex64_t  alpha,const bblas_complex64_t ** a,const int lda,const bblas_complex64_t ** x,const int incx,const bblas_complex64_t  beta,bblas_complex64_t ** y,const int incy,int *info);
void blas_chpmv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const int n,const bblas_complex32_t  alpha,const bblas_complex32_t ** ap,const bblas_complex32_t ** x,const int incx,const bblas_complex32_t  beta,bblas_complex32_t ** y,const int incy,int *info);
void blas_zhpmv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const int n,const bblas_complex64_t  alpha,const bblas_complex64_t ** ap,const bblas_complex64_t ** x,const int incx,const bblas_complex64_t  beta,bblas_complex64_t ** y,const int incy,int *info);
void blas_ssymv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const int n,const float alpha,const float ** a,const int lda,const float ** x,const int incx,const float beta,float ** y,const int incy,int *info);
void blas_dsymv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const int n,const double alpha,const double ** a,const int lda,const double ** x,const int incx,const double beta,double ** y,const int incy,int *info);
void blas_ssbmv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const int n,const int k,const float alpha,const float ** a,const int lda,const float ** x,const int incx,const float beta,float ** y,const int incy,int *info);
void blas_dsbmv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const int n,const int k,const double alpha,const double ** a,const int lda,const double ** x,const int incx,const double beta,double ** y,const int incy,int *info);
void blas_sspmv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const int n,const float alpha,const float ** ap,const float ** x,const int incx,const float beta,float ** y,const int incy,int *info);
void blas_dspmv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const int n,const double alpha,const double ** ap,const double ** x,const int incx,const double beta,double ** y,const int incy,int *info);
void blas_strmv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const bblas_enum_t diag,const int n,const float ** a,const int lda,float ** x,const int incx,int *info);
void blas_dtrmv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const bblas_enum_t diag,const int n,const double ** a,const int lda,double ** x,const int incx,int *info);
void blas_ctrmv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const bblas_enum_t diag,const int n,const bblas_complex32_t ** a,const int lda,bblas_complex32_t ** x,const int incx,int *info);
void blas_ztrmv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const bblas_enum_t diag,const int n,const bblas_complex64_t ** a,const int lda,bblas_complex64_t ** x,const int incx,int *info);
void blas_stbmv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const bblas_enum_t diag,const int n,const int k,const float ** a,const int lda,float ** x,const int incx,int *info);
void blas_dtbmv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const bblas_enum_t diag,const int n,const int k,const double ** a,const int lda,double ** x,const int incx,int *info);
void blas_ctbmv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const bblas_enum_t diag,const int n,const int k,const bblas_complex32_t ** a,const int lda,bblas_complex32_t ** x,const int incx,int *info);
void blas_ztbmv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const bblas_enum_t diag,const int n,const int k,const bblas_complex64_t ** a,const int lda,bblas_complex64_t ** x,const int incx,int *info);
void blas_stpmv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const bblas_enum_t diag,const int n,const float ** ap,float ** x,const int incx,int *info);
void blas_dtpmv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const bblas_enum_t diag,const int n,const double ** ap,double ** x,const int incx,int *info);
void blas_ctpmv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const bblas_enum_t diag,const int n,const bblas_complex32_t ** ap,bblas_complex32_t ** x,const int incx,int *info);
void blas_ztpmv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const bblas_enum_t diag,const int n,const bblas_complex64_t ** ap,bblas_complex64_t ** x,const int incx,int *info);
void blas_strsv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const bblas_enum_t diag,const int n,const float ** a,const int lda,float ** x,const int incx,int *info);
void blas_dtrsv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const bblas_enum_t diag,const int n,const double ** a,const int lda,double ** x,const int incx,int *info);
void blas_ctrsv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const bblas_enum_t diag,const int n,const bblas_complex32_t ** a,const int lda,bblas_complex32_t ** x,const int incx,int *info);
void blas_ztrsv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const bblas_enum_t diag,const int n,const bblas_complex64_t ** a,const int lda,bblas_complex64_t ** x,const int incx,int *info);
void blas_stbsv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const bblas_enum_t diag,const int n,const int k,const float ** a,const int lda,float ** x,const int incx,int *info);
void blas_dtbsv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const bblas_enum_t diag,const int n,const int k,const double ** a,const int lda,double ** x,const int incx,int *info);
void blas_ctbsv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const bblas_enum_t diag,const int n,const int k,const bblas_complex32_t ** a,const int lda,bblas_complex32_t ** x,const int incx,int *info);
void blas_ztbsv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const bblas_enum_t diag,const int n,const int k,const bblas_complex64_t ** a,const int lda,bblas_complex64_t ** x,const int incx,int *info);
void blas_stpsv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const bblas_enum_t diag,const int n,const float ** ap,float ** x,const int incx,int *info);
void blas_dtpsv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const bblas_enum_t diag,const int n,const double ** ap,double ** x,const int incx,int *info);
void blas_ctpsv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const bblas_enum_t diag,const int n,const bblas_complex32_t ** ap,bblas_complex32_t ** x,const int incx,int *info);
void blas_ztpsv_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const bblas_enum_t diag,const int n,const bblas_complex64_t ** ap,bblas_complex64_t ** x,const int incx,int *info);
void blas_sger_batchf(const int group_size,const bblas_enum_t layout,const int m,const int n,const float alpha,const float ** x,const int incx,const float ** y,const int incy,float ** a,const int lda,int *info);
void blas_dger_batchf(const int group_size,const bblas_enum_t layout,const int m,const int n,const double alpha,const double ** x,const int incx,const double ** y,const int incy,double ** a,const int lda,int *info);
void blas_cgeru_batchf(const int group_size,const bblas_enum_t layout,const int m,const int n,const bblas_complex32_t  alpha,const bblas_complex32_t ** x,const int incx,const bblas_complex32_t ** y,const int incy,bblas_complex32_t ** a,const int lda,int *info);
void blas_zgeru_batchf(const int group_size,const bblas_enum_t layout,const int m,const int n,const bblas_complex64_t  alpha,const bblas_complex64_t ** x,const int incx,const bblas_complex64_t ** y,const int incy,bblas_complex64_t ** a,const int lda,int *info);
void blas_cgerc_batchf(const int group_size,const bblas_enum_t layout,const int m,const int n,const bblas_complex32_t  alpha,const bblas_complex32_t ** x,const int incx,const bblas_complex32_t ** y,const int incy,bblas_complex32_t ** a,const int lda,int *info);
void blas_zgerc_batchf(const int group_size,const bblas_enum_t layout,const int m,const int n,const bblas_complex64_t  alpha,const bblas_complex64_t ** x,const int incx,const bblas_complex64_t ** y,const int incy,bblas_complex64_t ** a,const int lda,int *info);
void blas_cher_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const int n,const float alpha,const bblas_complex32_t ** x,const int incx,bblas_complex32_t ** a,const int lda,int *info);
void blas_zher_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const int n,const double alpha,const bblas_complex64_t ** x,const int incx,bblas_complex64_t ** a,const int lda,int *info);
void blas_chpr_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const int n,const float alpha,const bblas_complex32_t ** x,const int incx,bblas_complex32_t ** ap,int *info);
void blas_zhpr_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const int n,const double alpha,const bblas_complex64_t ** x,const int incx,bblas_complex64_t ** ap,int *info);
void blas_cher2_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const int n,const bblas_complex32_t  alpha,const bblas_complex32_t ** x,const int incx,const bblas_complex32_t ** y,const int incy,bblas_complex32_t ** a,const int lda,int *info);
void blas_zher2_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const int n,const bblas_complex64_t  alpha,const bblas_complex64_t ** x,const int incx,const bblas_complex64_t ** y,const int incy,bblas_complex64_t ** a,const int lda,int *info);
void blas_chpr2_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const int n,const bblas_complex32_t  alpha,const bblas_complex32_t ** x,const int incx,const bblas_complex32_t ** y,const int incy,bblas_complex32_t ** ap,int *info);
void blas_zhpr2_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const int n,const bblas_complex64_t  alpha,const bblas_complex64_t ** x,const int incx,const bblas_complex64_t ** y,const int incy,bblas_complex64_t ** ap,int *info);
void blas_ssyr_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const int n,const float alpha,const float ** x,const int incx,float ** a,const int lda,int *info);
void blas_dsyr_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const int n,const double alpha,const double ** x,const int incx,double ** a,const int lda,int *info);
void blas_sspr_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const int n,const float alpha,const float ** x,const int incx,float ** ap,int *info);
void blas_dspr_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const int n,const double alpha,const double ** x,const int incx,double ** ap,int *info);
void blas_ssyr2_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const int n,const float alpha,const float ** x,const int incx,const float ** y,const int incy,float ** a,const int lda,int *info);
void blas_dsyr2_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const int n,const double alpha,const double ** x,const int incx,const double ** y,const int incy,double ** a,const int lda,int *info);
void blas_sspr2_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const int n,const float alpha,const float ** x,const int incx,const float ** y,const int incy,float ** ap,int *info);
void blas_dspr2_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const int n,const double alpha,const double ** x,const int incx,const double ** y,const int incy,double ** ap,int *info);
void blas_sgemm_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t transa,const bblas_enum_t transb,const int m,const int n,const int k,const float alpha,const float ** a,const int lda,const float ** b,const int ldb,const float beta,float ** c,const int ldc,int *info);
void blas_dgemm_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t transa,const bblas_enum_t transb,const int m,const int n,const int k,const double alpha,const double ** a,const int lda,const double ** b,const int ldb,const double beta,double ** c,const int ldc,int *info);
void blas_cgemm_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t transa,const bblas_enum_t transb,const int m,const int n,const int k,const bblas_complex32_t  alpha,const bblas_complex32_t ** a,const int lda,const bblas_complex32_t ** b,const int ldb,const bblas_complex32_t  beta,bblas_complex32_t ** c,const int ldc,int *info);
void blas_zgemm_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t transa,const bblas_enum_t transb,const int m,const int n,const int k,const bblas_complex64_t  alpha,const bblas_complex64_t ** a,const int lda,const bblas_complex64_t ** b,const int ldb,const bblas_complex64_t  beta,bblas_complex64_t ** c,const int ldc,int *info);
void blas_ssymm_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t side,const bblas_enum_t uplo,const int m,const int n,const float alpha,const float ** a,const int lda,const float ** b,const int ldb,const float beta,float ** c,const int ldc,int *info);
void blas_dsymm_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t side,const bblas_enum_t uplo,const int m,const int n,const double alpha,const double ** a,const int lda,const double ** b,const int ldb,const double beta,double ** c,const int ldc,int *info);
void blas_csymm_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t side,const bblas_enum_t uplo,const int m,const int n,const bblas_complex32_t  alpha,const bblas_complex32_t ** a,const int lda,const bblas_complex32_t ** b,const int ldb,const bblas_complex32_t  beta,bblas_complex32_t ** c,const int ldc,int *info);
void blas_zsymm_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t side,const bblas_enum_t uplo,const int m,const int n,const bblas_complex64_t  alpha,const bblas_complex64_t ** a,const int lda,const bblas_complex64_t ** b,const int ldb,const bblas_complex64_t  beta,bblas_complex64_t ** c,const int ldc,int *info);
void blas_chemm_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t side,const bblas_enum_t uplo,const int m,const int n,const bblas_complex32_t  alpha,const bblas_complex32_t ** a,const int lda,const bblas_complex32_t ** b,const int ldb,const bblas_complex32_t  beta,bblas_complex32_t ** c,const int ldc,int *info);
void blas_zhemm_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t side,const bblas_enum_t uplo,const int m,const int n,const bblas_complex64_t  alpha,const bblas_complex64_t ** a,const int lda,const bblas_complex64_t ** b,const int ldb,const bblas_complex64_t  beta,bblas_complex64_t ** c,const int ldc,int *info);
void blas_ssyrk_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const int n,const int k,const float alpha,const float ** a,const int lda,const float beta,float ** c,const int ldc,int *info);
void blas_dsyrk_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const int n,const int k,const double alpha,const double ** a,const int lda,const double beta,double ** c,const int ldc,int *info);
void blas_csyrk_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const int n,const int k,const bblas_complex32_t  alpha,const bblas_complex32_t ** a,const int lda,const bblas_complex32_t  beta,bblas_complex32_t ** c,const int ldc,int *info);
void blas_zsyrk_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const int n,const int k,const bblas_complex64_t  alpha,const bblas_complex64_t ** a,const int lda,const bblas_complex64_t  beta,bblas_complex64_t ** c,const int ldc,int *info);
void blas_cherk_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const int n,const int k,const float alpha,const bblas_complex32_t ** a,const int lda,const float beta,bblas_complex32_t ** c,const int ldc,int *info);
void blas_zherk_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const int n,const int k,const double alpha,const bblas_complex64_t ** a,const int lda,const double beta,bblas_complex64_t ** c,const int ldc,int *info);
void blas_ssyr2k_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const int n,const int k,const float alpha,const float ** a,const int lda,const float ** b,const int ldb,const float beta,float ** c,const int ldc,int *info);
void blas_dsyr2k_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const int n,const int k,const double alpha,const double ** a,const int lda,const double ** b,const int ldb,const double beta,double ** c,const int ldc,int *info);
void blas_csyr2k_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const int n,const int k,const bblas_complex32_t  alpha,const bblas_complex32_t ** a,const int lda,const bblas_complex32_t ** b,const int ldb,const bblas_complex32_t  beta,bblas_complex32_t ** c,const int ldc,int *info);
void blas_zsyr2k_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const int n,const int k,const bblas_complex64_t  alpha,const bblas_complex64_t ** a,const int lda,const bblas_complex64_t ** b,const int ldb,const bblas_complex64_t  beta,bblas_complex64_t ** c,const int ldc,int *info);
void blas_cher2k_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const int n,const int k,const bblas_complex32_t  alpha,const bblas_complex32_t** a,const int lda,const bblas_complex32_t ** b,const int ldb,const float beta,bblas_complex32_t ** c,const int ldc,int *info);
void blas_zher2k_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t uplo,const bblas_enum_t trans,const int n,const int k,const bblas_complex64_t  alpha,const bblas_complex64_t** a,const int lda,const bblas_complex64_t ** b,const int ldb,const double beta,bblas_complex64_t ** c,const int ldc,int *info);
void blas_strmm_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t side,const bblas_enum_t uplo,const bblas_enum_t transa,const bblas_enum_t diag,const int m,const int n,const float alpha,const float ** a,const int lda,float ** b,const int ldb,int *info);
void blas_dtrmm_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t side,const bblas_enum_t uplo,const bblas_enum_t transa,const bblas_enum_t diag,const int m,const int n,const double alpha,const double ** a,const int lda,double ** b,const int ldb,int *info);
void blas_ctrmm_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t side,const bblas_enum_t uplo,const bblas_enum_t transa,const bblas_enum_t diag,const int m,const int n,const bblas_complex32_t  alpha,const bblas_complex32_t ** a,const int lda,bblas_complex32_t ** b,const int ldb,int *info);
void blas_ztrmm_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t side,const bblas_enum_t uplo,const bblas_enum_t transa,const bblas_enum_t diag,const int m,const int n,const bblas_complex64_t  alpha,const bblas_complex64_t ** a,const int lda,bblas_complex64_t ** b,const int ldb,int *info);
void blas_strsm_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t side,const bblas_enum_t uplo,const bblas_enum_t transa,const bblas_enum_t diag,const int m,const int n,const float alpha,const float ** a,const int lda,float ** b,const int ldb,int *info);
void blas_dtrsm_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t side,const bblas_enum_t uplo,const bblas_enum_t transa,const bblas_enum_t diag,const int m,const int n,const double alpha,const double ** a,const int lda,double ** b,const int ldb,int *info);
void blas_ctrsm_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t side,const bblas_enum_t uplo,const bblas_enum_t transa,const bblas_enum_t diag,const int m,const int n,const bblas_complex32_t  alpha,const bblas_complex32_t ** a,const int lda,bblas_complex32_t ** b,const int ldb,int *info);
void blas_ztrsm_batchf(const int group_size,const bblas_enum_t layout,const bblas_enum_t side,const bblas_enum_t uplo,const bblas_enum_t transa,const bblas_enum_t diag,const int m,const int n,const bblas_complex64_t  alpha,const bblas_complex64_t ** a,const int lda,bblas_complex64_t ** b,const int ldb,int *info);
void blas_srotg_batch(const int group_count,const int *group_size,float ** a,float ** b,float ** c,float ** s,int *info);
void blas_drotg_batch(const int group_count,const int *group_size,double ** a,double ** b,double ** c,double ** s,int *info);
void blas_srotmg_batch(const int group_count,const int *group_size,float ** d1,float ** d2,float ** x1,const float* y1,float ** param,int *info);
void blas_drotmg_batch(const int group_count,const int *group_size,double ** d1,double ** d2,double ** x1,const double* y1,double ** param,int *info);
void blas_srot_batch(const int group_count,const int *group_size,const int* n,float ** x,const int* incx,float ** y,const int* incy,const float* c1,const float* s,int *info);
void blas_drot_batch(const int group_count,const int *group_size,const int* n,double ** x,const int* incx,double ** y,const int* incy,const double* c1,const double* s,int *info);
void blas_srotm_batch(const int group_count,const int *group_size,const int* n,float ** x,const int* incx,float ** y,const int* incy,const float ** param,int *info);
void blas_drotm_batch(const int group_count,const int *group_size,const int* n,double ** x,const int* incx,double ** y,const int* incy,const double ** param,int *info);
void blas_sswap_batch(const int group_count,const int *group_size,const int* n,float ** x,const int* incx,float ** y,const int* incy,int *info);
void blas_dswap_batch(const int group_count,const int *group_size,const int* n,double ** x,const int* incx,double ** y,const int* incy,int *info);
void blas_cswap_batch(const int group_count,const int *group_size,const int* n,bblas_complex32_t ** x,const int* incx,bblas_complex32_t ** y,const int* incy,int *info);
void blas_zswap_batch(const int group_count,const int *group_size,const int* n,bblas_complex64_t ** x,const int* incx,bblas_complex64_t ** y,const int* incy,int *info);
void blas_sscal_batch(const int group_count,const int *group_size,const int* n,const float* a,float ** x,const int* incx,int *info);
void blas_dscal_batch(const int group_count,const int *group_size,const int* n,const double* a,double ** x,const int* incx,int *info);
void blas_cscal_batch(const int group_count,const int *group_size,const int* n,const bblas_complex32_t * a,bblas_complex32_t ** x,const int* incx,int *info);
void blas_zscal_batch(const int group_count,const int *group_size,const int* n,const bblas_complex64_t * a,bblas_complex64_t ** x,const int* incx,int *info);
void blas_csscal_batch(const int group_count,const int *group_size,const int* n,const float* a,bblas_complex32_t ** x,const int* incx,int *info);
void blas_zdscal_batch(const int group_count,const int *group_size,const int* n,const double* a,bblas_complex64_t ** x,const int* incx,int *info);
void blas_scopy_batch(const int group_count,const int *group_size,const int* n,const float ** x,const int* incx,float ** y,const int* incy,int *info);
void blas_dcopy_batch(const int group_count,const int *group_size,const int* n,const double ** x,const int* incx,double ** y,const int* incy,int *info);
void blas_ccopy_batch(const int group_count,const int *group_size,const int* n,const bblas_complex32_t ** x,const int* incx,bblas_complex32_t ** y,const int* incy,int *info);
void blas_zcopy_batch(const int group_count,const int *group_size,const int* n,const bblas_complex64_t ** x,const int* incx,bblas_complex64_t ** y,const int* incy,int *info);
void blas_saxpy_batch(const int group_count,const int *group_size,const int* n,const float* a,const float ** x,const int* incx,float ** y,const int* incy,int *info);
void blas_daxpy_batch(const int group_count,const int *group_size,const int* n,const double* a,const double ** x,const int* incx,double ** y,const int* incy,int *info);
void blas_caxpy_batch(const int group_count,const int *group_size,const int* n,const bblas_complex32_t * a,const bblas_complex32_t ** x,const int* incx,bblas_complex32_t ** y,const int* incy,int *info);
void blas_zaxpy_batch(const int group_count,const int *group_size,const int* n,const bblas_complex64_t * a,const bblas_complex64_t ** x,const int* incx,bblas_complex64_t ** y,const int* incy,int *info);
void blas_sdot_batch(const int group_count,const int *group_size,const int* n,const float ** x,const int* incx,const float ** y,const int* incy,float* ret_cblas_sdot,int *info);
void blas_ddot_batch(const int group_count,const int *group_size,const int* n,const double ** x,const int* incx,const double ** y,const int* incy,double* ret_cblas_ddot,int *info);
void blas_dsdot_batch(const int group_count,const int *group_size,const int* n,const float ** x,const int* incx,const float ** y,const int* incy,double* ret_cblas_dsdot,int *info);
void blas_cdotu_batch(const int group_count,const int *group_size,const int* n,const bblas_complex32_t ** x,const int* incx,const bblas_complex32_t ** y,const int* incy,bblas_complex32_t ** dotu,int *info);
void blas_zdotu_batch(const int group_count,const int *group_size,const int* n,const bblas_complex64_t ** x,const int* incx,const bblas_complex64_t ** y,const int* incy,bblas_complex64_t ** dotu,int *info);
void blas_cdotc_batch(const int group_count,const int *group_size,const int* n,const bblas_complex32_t ** x,const int* incx,const bblas_complex32_t ** y,const int* incy,bblas_complex32_t ** dotc,int *info);
void blas_zdotc_batch(const int group_count,const int *group_size,const int* n,const bblas_complex64_t ** x,const int* incx,const bblas_complex64_t ** y,const int* incy,bblas_complex64_t ** dotc,int *info);
void blas_sdsdot_batch(const int group_count,const int *group_size,const int* n,const float* sb,const float ** sx,const int* incx,const float ** sy,const int* incy,float* ret_cblas_sdsdot,int *info);
void blas_snrm2_batch(const int group_count,const int *group_size,const int* n,const float ** x,const int* incx,float* ret_cblas_snrm2,int *info);
void blas_dnrm2_batch(const int group_count,const int *group_size,const int* n,const double ** x,const int* incx,double* ret_cblas_dnrm2,int *info);
void blas_scnrm2_batch(const int group_count,const int *group_size,const int* n,const bblas_complex32_t ** x,const int* incx,float* ret_cblas_scnrm2,int *info);
void blas_dznrm2_batch(const int group_count,const int *group_size,const int* n,const bblas_complex64_t ** x,const int* incx,double* ret_cblas_dznrm2,int *info);
void blas_sasum_batch(const int group_count,const int *group_size,const int* n,const float ** x,const int* incx,float* ret_cblas_sasum,int *info);
void blas_dasum_batch(const int group_count,const int *group_size,const int* n,const double ** x,const int* incx,double* ret_cblas_dasum,int *info);
void blas_scasum_batch(const int group_count,const int *group_size,const int* n,const bblas_complex32_t ** x,const int* incx,float* ret_cblas_scasum,int *info);
void blas_dzasum_batch(const int group_count,const int *group_size,const int* n,const bblas_complex64_t ** x,const int* incx,double* ret_cblas_dzasum,int *info);
void blas_isamax_batch(const int group_count,const int *group_size,const int* n,const float ** x,const int* incx,int* ret_cblas_isamax,int *info);
void blas_idamax_batch(const int group_count,const int *group_size,const int* n,const double ** x,const int* incx,int* ret_cblas_idamax,int *info);
void blas_icamax_batch(const int group_count,const int *group_size,const int* n,const bblas_complex32_t ** x,const int* incx,int* ret_cblas_icamax,int *info);
void blas_izamax_batch(const int group_count,const int *group_size,const int* n,const bblas_complex64_t ** x,const int* incx,int* ret_cblas_izamax,int *info);
void blas_sgemv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* transa,const int* m,const int* n,const float* alpha,const float ** a,const int* lda,const float ** x,const int* incx,const float* beta,float ** y,const int* incy,int *info);
void blas_dgemv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* transa,const int* m,const int* n,const double* alpha,const double ** a,const int* lda,const double ** x,const int* incx,const double* beta,double ** y,const int* incy,int *info);
void blas_cgemv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* transa,const int* m,const int* n,const bblas_complex32_t * alpha,const bblas_complex32_t ** a,const int* lda,const bblas_complex32_t ** x,const int* incx,const bblas_complex32_t * beta,bblas_complex32_t ** y,const int* incy,int *info);
void blas_zgemv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* transa,const int* m,const int* n,const bblas_complex64_t * alpha,const bblas_complex64_t ** a,const int* lda,const bblas_complex64_t ** x,const int* incx,const bblas_complex64_t * beta,bblas_complex64_t ** y,const int* incy,int *info);
void blas_sgbmv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* trans,const int* m,const int* n,const int* kl,const int* ku,const float* alpha,const float ** a,const int* lda,const float ** x,const int* incx,const float* beta,float ** y,const int* incy,int *info);
void blas_dgbmv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* trans,const int* m,const int* n,const int* kl,const int* ku,const double* alpha,const double ** a,const int* lda,const double ** x,const int* incx,const double* beta,double ** y,const int* incy,int *info);
void blas_cgbmv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* trans,const int* m,const int* n,const int* kl,const int* ku,const bblas_complex32_t * alpha,const bblas_complex32_t ** a,const int* lda,const bblas_complex32_t ** x,const int* incx,const bblas_complex32_t * beta,bblas_complex32_t ** y,const int* incy,int *info);
void blas_zgbmv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* trans,const int* m,const int* n,const int* kl,const int* ku,const bblas_complex64_t * alpha,const bblas_complex64_t ** a,const int* lda,const bblas_complex64_t ** x,const int* incx,const bblas_complex64_t * beta,bblas_complex64_t ** y,const int* incy,int *info);
void blas_chemv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const int* n,const bblas_complex32_t * alpha,const bblas_complex32_t ** a,const int* lda,const bblas_complex32_t ** x,const int* incx,const bblas_complex32_t * beta,bblas_complex32_t ** y,const int* incy,int *info);
void blas_zhemv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const int* n,const bblas_complex64_t * alpha,const bblas_complex64_t ** a,const int* lda,const bblas_complex64_t ** x,const int* incx,const bblas_complex64_t * beta,bblas_complex64_t ** y,const int* incy,int *info);
void blas_chbmv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const int* n,const int* k,const bblas_complex32_t * alpha,const bblas_complex32_t ** a,const int* lda,const bblas_complex32_t ** x,const int* incx,const bblas_complex32_t * beta,bblas_complex32_t ** y,const int* incy,int *info);
void blas_zhbmv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const int* n,const int* k,const bblas_complex64_t * alpha,const bblas_complex64_t ** a,const int* lda,const bblas_complex64_t ** x,const int* incx,const bblas_complex64_t * beta,bblas_complex64_t ** y,const int* incy,int *info);
void blas_chpmv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const int* n,const bblas_complex32_t * alpha,const bblas_complex32_t ** ap,const bblas_complex32_t ** x,const int* incx,const bblas_complex32_t * beta,bblas_complex32_t ** y,const int* incy,int *info);
void blas_zhpmv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const int* n,const bblas_complex64_t * alpha,const bblas_complex64_t ** ap,const bblas_complex64_t ** x,const int* incx,const bblas_complex64_t * beta,bblas_complex64_t ** y,const int* incy,int *info);
void blas_ssymv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const int* n,const float* alpha,const float ** a,const int* lda,const float ** x,const int* incx,const float* beta,float ** y,const int* incy,int *info);
void blas_dsymv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const int* n,const double* alpha,const double ** a,const int* lda,const double ** x,const int* incx,const double* beta,double ** y,const int* incy,int *info);
void blas_ssbmv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const int* n,const int* k,const float* alpha,const float ** a,const int* lda,const float ** x,const int* incx,const float* beta,float ** y,const int* incy,int *info);
void blas_dsbmv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const int* n,const int* k,const double* alpha,const double ** a,const int* lda,const double ** x,const int* incx,const double* beta,double ** y,const int* incy,int *info);
void blas_sspmv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const int* n,const float* alpha,const float ** ap,const float ** x,const int* incx,const float* beta,float ** y,const int* incy,int *info);
void blas_dspmv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const int* n,const double* alpha,const double ** ap,const double ** x,const int* incx,const double* beta,double ** y,const int* incy,int *info);
void blas_strmv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const bblas_enum_t* diag,const int* n,const float ** a,const int* lda,float ** x,const int* incx,int *info);
void blas_dtrmv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const bblas_enum_t* diag,const int* n,const double ** a,const int* lda,double ** x,const int* incx,int *info);
void blas_ctrmv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const bblas_enum_t* diag,const int* n,const bblas_complex32_t ** a,const int* lda,bblas_complex32_t ** x,const int* incx,int *info);
void blas_ztrmv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const bblas_enum_t* diag,const int* n,const bblas_complex64_t ** a,const int* lda,bblas_complex64_t ** x,const int* incx,int *info);
void blas_stbmv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const bblas_enum_t* diag,const int* n,const int* k,const float ** a,const int* lda,float ** x,const int* incx,int *info);
void blas_dtbmv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const bblas_enum_t* diag,const int* n,const int* k,const double ** a,const int* lda,double ** x,const int* incx,int *info);
void blas_ctbmv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const bblas_enum_t* diag,const int* n,const int* k,const bblas_complex32_t ** a,const int* lda,bblas_complex32_t ** x,const int* incx,int *info);
void blas_ztbmv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const bblas_enum_t* diag,const int* n,const int* k,const bblas_complex64_t ** a,const int* lda,bblas_complex64_t ** x,const int* incx,int *info);
void blas_stpmv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const bblas_enum_t* diag,const int* n,const float ** ap,float ** x,const int* incx,int *info);
void blas_dtpmv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const bblas_enum_t* diag,const int* n,const double ** ap,double ** x,const int* incx,int *info);
void blas_ctpmv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const bblas_enum_t* diag,const int* n,const bblas_complex32_t ** ap,bblas_complex32_t ** x,const int* incx,int *info);
void blas_ztpmv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const bblas_enum_t* diag,const int* n,const bblas_complex64_t ** ap,bblas_complex64_t ** x,const int* incx,int *info);
void blas_strsv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const bblas_enum_t* diag,const int* n,const float ** a,const int* lda,float ** x,const int* incx,int *info);
void blas_dtrsv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const bblas_enum_t* diag,const int* n,const double ** a,const int* lda,double ** x,const int* incx,int *info);
void blas_ctrsv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const bblas_enum_t* diag,const int* n,const bblas_complex32_t ** a,const int* lda,bblas_complex32_t ** x,const int* incx,int *info);
void blas_ztrsv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const bblas_enum_t* diag,const int* n,const bblas_complex64_t ** a,const int* lda,bblas_complex64_t ** x,const int* incx,int *info);
void blas_stbsv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const bblas_enum_t* diag,const int* n,const int* k,const float ** a,const int* lda,float ** x,const int* incx,int *info);
void blas_dtbsv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const bblas_enum_t* diag,const int* n,const int* k,const double ** a,const int* lda,double ** x,const int* incx,int *info);
void blas_ctbsv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const bblas_enum_t* diag,const int* n,const int* k,const bblas_complex32_t ** a,const int* lda,bblas_complex32_t ** x,const int* incx,int *info);
void blas_ztbsv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const bblas_enum_t* diag,const int* n,const int* k,const bblas_complex64_t ** a,const int* lda,bblas_complex64_t ** x,const int* incx,int *info);
void blas_stpsv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const bblas_enum_t* diag,const int* n,const float ** ap,float ** x,const int* incx,int *info);
void blas_dtpsv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const bblas_enum_t* diag,const int* n,const double ** ap,double ** x,const int* incx,int *info);
void blas_ctpsv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const bblas_enum_t* diag,const int* n,const bblas_complex32_t ** ap,bblas_complex32_t ** x,const int* incx,int *info);
void blas_ztpsv_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const bblas_enum_t* diag,const int* n,const bblas_complex64_t ** ap,bblas_complex64_t ** x,const int* incx,int *info);
void blas_sger_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const int* m,const int* n,const float* alpha,const float ** x,const int* incx,const float ** y,const int* incy,float ** a,const int* lda,int *info);
void blas_dger_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const int* m,const int* n,const double* alpha,const double ** x,const int* incx,const double ** y,const int* incy,double ** a,const int* lda,int *info);
void blas_cgeru_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const int* m,const int* n,const bblas_complex32_t * alpha,const bblas_complex32_t ** x,const int* incx,const bblas_complex32_t ** y,const int* incy,bblas_complex32_t ** a,const int* lda,int *info);
void blas_zgeru_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const int* m,const int* n,const bblas_complex64_t * alpha,const bblas_complex64_t ** x,const int* incx,const bblas_complex64_t ** y,const int* incy,bblas_complex64_t ** a,const int* lda,int *info);
void blas_cgerc_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const int* m,const int* n,const bblas_complex32_t * alpha,const bblas_complex32_t ** x,const int* incx,const bblas_complex32_t ** y,const int* incy,bblas_complex32_t ** a,const int* lda,int *info);
void blas_zgerc_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const int* m,const int* n,const bblas_complex64_t * alpha,const bblas_complex64_t ** x,const int* incx,const bblas_complex64_t ** y,const int* incy,bblas_complex64_t ** a,const int* lda,int *info);
void blas_cher_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const int* n,const float* alpha,const bblas_complex32_t ** x,const int* incx,bblas_complex32_t ** a,const int* lda,int *info);
void blas_zher_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const int* n,const double* alpha,const bblas_complex64_t ** x,const int* incx,bblas_complex64_t ** a,const int* lda,int *info);
void blas_chpr_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const int* n,const float* alpha,const bblas_complex32_t ** x,const int* incx,bblas_complex32_t ** ap,int *info);
void blas_zhpr_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const int* n,const double* alpha,const bblas_complex64_t ** x,const int* incx,bblas_complex64_t ** ap,int *info);
void blas_cher2_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const int* n,const bblas_complex32_t * alpha,const bblas_complex32_t ** x,const int* incx,const bblas_complex32_t ** y,const int* incy,bblas_complex32_t ** a,const int* lda,int *info);
void blas_zher2_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const int* n,const bblas_complex64_t * alpha,const bblas_complex64_t ** x,const int* incx,const bblas_complex64_t ** y,const int* incy,bblas_complex64_t ** a,const int* lda,int *info);
void blas_chpr2_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const int* n,const bblas_complex32_t * alpha,const bblas_complex32_t ** x,const int* incx,const bblas_complex32_t ** y,const int* incy,bblas_complex32_t ** ap,int *info);
void blas_zhpr2_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const int* n,const bblas_complex64_t * alpha,const bblas_complex64_t ** x,const int* incx,const bblas_complex64_t ** y,const int* incy,bblas_complex64_t ** ap,int *info);
void blas_ssyr_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const int* n,const float* alpha,const float ** x,const int* incx,float ** a,const int* lda,int *info);
void blas_dsyr_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const int* n,const double* alpha,const double ** x,const int* incx,double ** a,const int* lda,int *info);
void blas_sspr_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const int* n,const float* alpha,const float ** x,const int* incx,float ** ap,int *info);
void blas_dspr_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const int* n,const double* alpha,const double ** x,const int* incx,double ** ap,int *info);
void blas_ssyr2_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const int* n,const float* alpha,const float ** x,const int* incx,const float ** y,const int* incy,float ** a,const int* lda,int *info);
void blas_dsyr2_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const int* n,const double* alpha,const double ** x,const int* incx,const double ** y,const int* incy,double ** a,const int* lda,int *info);
void blas_sspr2_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const int* n,const float* alpha,const float ** x,const int* incx,const float ** y,const int* incy,float ** ap,int *info);
void blas_dspr2_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const int* n,const double* alpha,const double ** x,const int* incx,const double ** y,const int* incy,double ** ap,int *info);
void blas_sgemm_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* transa,const bblas_enum_t* transb,const int* m,const int* n,const int* k,const float* alpha,const float ** a,const int* lda,const float ** b,const int* ldb,const float* beta,float ** c,const int* ldc,int *info);
void blas_dgemm_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* transa,const bblas_enum_t* transb,const int* m,const int* n,const int* k,const double* alpha,const double ** a,const int* lda,const double ** b,const int* ldb,const double* beta,double ** c,const int* ldc,int *info);
void blas_cgemm_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* transa,const bblas_enum_t* transb,const int* m,const int* n,const int* k,const bblas_complex32_t * alpha,const bblas_complex32_t ** a,const int* lda,const bblas_complex32_t ** b,const int* ldb,const bblas_complex32_t * beta,bblas_complex32_t ** c,const int* ldc,int *info);
void blas_zgemm_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* transa,const bblas_enum_t* transb,const int* m,const int* n,const int* k,const bblas_complex64_t * alpha,const bblas_complex64_t ** a,const int* lda,const bblas_complex64_t ** b,const int* ldb,const bblas_complex64_t * beta,bblas_complex64_t ** c,const int* ldc,int *info);
void blas_ssymm_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* side,const bblas_enum_t* uplo,const int* m,const int* n,const float* alpha,const float ** a,const int* lda,const float ** b,const int* ldb,const float* beta,float ** c,const int* ldc,int *info);
void blas_dsymm_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* side,const bblas_enum_t* uplo,const int* m,const int* n,const double* alpha,const double ** a,const int* lda,const double ** b,const int* ldb,const double* beta,double ** c,const int* ldc,int *info);
void blas_csymm_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* side,const bblas_enum_t* uplo,const int* m,const int* n,const bblas_complex32_t * alpha,const bblas_complex32_t ** a,const int* lda,const bblas_complex32_t ** b,const int* ldb,const bblas_complex32_t * beta,bblas_complex32_t ** c,const int* ldc,int *info);
void blas_zsymm_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* side,const bblas_enum_t* uplo,const int* m,const int* n,const bblas_complex64_t * alpha,const bblas_complex64_t ** a,const int* lda,const bblas_complex64_t ** b,const int* ldb,const bblas_complex64_t * beta,bblas_complex64_t ** c,const int* ldc,int *info);
void blas_chemm_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* side,const bblas_enum_t* uplo,const int* m,const int* n,const bblas_complex32_t * alpha,const bblas_complex32_t ** a,const int* lda,const bblas_complex32_t ** b,const int* ldb,const bblas_complex32_t * beta,bblas_complex32_t ** c,const int* ldc,int *info);
void blas_zhemm_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* side,const bblas_enum_t* uplo,const int* m,const int* n,const bblas_complex64_t * alpha,const bblas_complex64_t ** a,const int* lda,const bblas_complex64_t ** b,const int* ldb,const bblas_complex64_t * beta,bblas_complex64_t ** c,const int* ldc,int *info);
void blas_ssyrk_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const int* n,const int* k,const float* alpha,const float ** a,const int* lda,const float* beta,float ** c,const int* ldc,int *info);
void blas_dsyrk_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const int* n,const int* k,const double* alpha,const double ** a,const int* lda,const double* beta,double ** c,const int* ldc,int *info);
void blas_csyrk_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const int* n,const int* k,const bblas_complex32_t * alpha,const bblas_complex32_t ** a,const int* lda,const bblas_complex32_t * beta,bblas_complex32_t ** c,const int* ldc,int *info);
void blas_zsyrk_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const int* n,const int* k,const bblas_complex64_t * alpha,const bblas_complex64_t ** a,const int* lda,const bblas_complex64_t * beta,bblas_complex64_t ** c,const int* ldc,int *info);
void blas_cherk_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const int* n,const int* k,const float* alpha,const bblas_complex32_t ** a,const int* lda,const float* beta,bblas_complex32_t ** c,const int* ldc,int *info);
void blas_zherk_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const int* n,const int* k,const double* alpha,const bblas_complex64_t ** a,const int* lda,const double* beta,bblas_complex64_t ** c,const int* ldc,int *info);
void blas_ssyr2k_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const int* n,const int* k,const float* alpha,const float ** a,const int* lda,const float ** b,const int* ldb,const float* beta,float ** c,const int* ldc,int *info);
void blas_dsyr2k_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const int* n,const int* k,const double* alpha,const double ** a,const int* lda,const double ** b,const int* ldb,const double* beta,double ** c,const int* ldc,int *info);
void blas_csyr2k_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const int* n,const int* k,const bblas_complex32_t * alpha,const bblas_complex32_t ** a,const int* lda,const bblas_complex32_t ** b,const int* ldb,const bblas_complex32_t * beta,bblas_complex32_t ** c,const int* ldc,int *info);
void blas_zsyr2k_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const int* n,const int* k,const bblas_complex64_t * alpha,const bblas_complex64_t ** a,const int* lda,const bblas_complex64_t ** b,const int* ldb,const bblas_complex64_t * beta,bblas_complex64_t ** c,const int* ldc,int *info);
void blas_cher2k_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const int* n,const int* k,const bblas_complex32_t * alpha,const bblas_complex32_t** a,const int* lda,const bblas_complex32_t ** b,const int* ldb,const float* beta,bblas_complex32_t ** c,const int* ldc,int *info);
void blas_zher2k_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* uplo,const bblas_enum_t* trans,const int* n,const int* k,const bblas_complex64_t * alpha,const bblas_complex64_t** a,const int* lda,const bblas_complex64_t ** b,const int* ldb,const double* beta,bblas_complex64_t ** c,const int* ldc,int *info);
void blas_strmm_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* side,const bblas_enum_t* uplo,const bblas_enum_t* transa,const bblas_enum_t* diag,const int* m,const int* n,const float* alpha,const float ** a,const int* lda,float ** b,const int* ldb,int *info);
void blas_dtrmm_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* side,const bblas_enum_t* uplo,const bblas_enum_t* transa,const bblas_enum_t* diag,const int* m,const int* n,const double* alpha,const double ** a,const int* lda,double ** b,const int* ldb,int *info);
void blas_ctrmm_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* side,const bblas_enum_t* uplo,const bblas_enum_t* transa,const bblas_enum_t* diag,const int* m,const int* n,const bblas_complex32_t * alpha,const bblas_complex32_t ** a,const int* lda,bblas_complex32_t ** b,const int* ldb,int *info);
void blas_ztrmm_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* side,const bblas_enum_t* uplo,const bblas_enum_t* transa,const bblas_enum_t* diag,const int* m,const int* n,const bblas_complex64_t * alpha,const bblas_complex64_t ** a,const int* lda,bblas_complex64_t ** b,const int* ldb,int *info);
void blas_strsm_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* side,const bblas_enum_t* uplo,const bblas_enum_t* transa,const bblas_enum_t* diag,const int* m,const int* n,const float* alpha,const float ** a,const int* lda,float ** b,const int* ldb,int *info);
void blas_dtrsm_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* side,const bblas_enum_t* uplo,const bblas_enum_t* transa,const bblas_enum_t* diag,const int* m,const int* n,const double* alpha,const double ** a,const int* lda,double ** b,const int* ldb,int *info);
void blas_ctrsm_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* side,const bblas_enum_t* uplo,const bblas_enum_t* transa,const bblas_enum_t* diag,const int* m,const int* n,const bblas_complex32_t * alpha,const bblas_complex32_t ** a,const int* lda,bblas_complex32_t ** b,const int* ldb,int *info);
void blas_ztrsm_batch(const int group_count,const int *group_size,const bblas_enum_t layout,const bblas_enum_t* side,const bblas_enum_t* uplo,const bblas_enum_t* transa,const bblas_enum_t* diag,const int* m,const int* n,const bblas_complex64_t * alpha,const bblas_complex64_t ** a,const int* lda,bblas_complex64_t ** b,const int* ldb,int *info);

#endif
