#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include <sys/time.h>

#include "batched_blas.h"
#include "batched_blas_test_common.h"

#define typ double

double getTime(){
  struct timeval t;
  gettimeofday(&t,NULL);
  return t.tv_sec + (double) t.tv_usec*1e-6;
}


int main(int argc, char *argv[])
{
  int i,j,l;
  int nsize,gsize,group_count,*group_size,*group_head;
  typ **d1,**d2,**x1,*y1,**param;
  typ **d1_temp,**d2_temp,**x1_temp,**param_temp;
  double ts,te;
  double error,max_error;
  int try_number;
  int total_batch_count;
  int i_try;
  
  if(argc < 5){
    printf("usage : ./(load module) <try_number> <group_count> <group_size (random base) > <n (random base)>\n");
    exit(1);
  }

  try_number = atoi(argv[1]);
  group_count = atoi(argv[2]);
  gsize = atoi(argv[3]);
  nsize = atoi(argv[4]);
  
  printf("name= %s, try_number= %d, group_count= %d, group_size= %d, nsize= %d\n", argv[0], try_number, group_count, gsize, nsize);

  srand48(123L);

  group_size = (int *)malloc(sizeof(int) * group_count);
  group_head = (int *)malloc(sizeof(int) * group_count);
  
  for(i_try = 0; i_try < try_number; i_try++){
    // set group size
    total_batch_count = 0;
    for(i = 0; i < group_count; i++){
      group_size[i] = random_int((int)((1.0-VAL_RANGE)*gsize),gsize);
      total_batch_count += group_size[i];
    }
    // set group head
    group_head[0] = 0;
    for(i = 1; i < group_count; i++){
      group_head[i] = group_head[i - 1] + group_size[i - 1];
    }
  
    d1 = (typ **)malloc(sizeof(typ *) * total_batch_count);
    d2 = (typ **)malloc(sizeof(typ *) * total_batch_count);
    x1 = (typ **)malloc(sizeof(typ *) * total_batch_count);
    y1 = (typ *)malloc(sizeof(typ) * total_batch_count);
    param = (typ **)malloc(sizeof(typ *) * total_batch_count);
    d1_temp = (typ **)malloc(sizeof(typ *) * total_batch_count);
    d2_temp = (typ **)malloc(sizeof(typ *) * total_batch_count);
    x1_temp = (typ **)malloc(sizeof(typ *) * total_batch_count);
    param_temp = (typ **)malloc(sizeof(typ *) * total_batch_count);
    
    for(i = 0; i < group_count; i++){
      for(j = 0; j < group_size[i]; j++){
        d1[group_head[i]+j] = (typ *)malloc(sizeof(typ) * 1);
        d2[group_head[i]+j] = (typ *)malloc(sizeof(typ) * 1);
        x1[group_head[i]+j] = (typ *)malloc(sizeof(typ) * 1);
        param[group_head[i]+j] = (typ *)malloc(sizeof(typ) * 5);
        d1_temp[group_head[i]+j] = (typ *)malloc(sizeof(typ) * 1);
        d2_temp[group_head[i]+j] = (typ *)malloc(sizeof(typ) * 1);
        x1_temp[group_head[i]+j] = (typ *)malloc(sizeof(typ) * 1);
        param_temp[group_head[i]+j] = (typ *)malloc(sizeof(typ) * 5);
        d1[group_head[i]+j][0] = d1_temp[group_head[i]+j][0] = fabs(drand48());
        d2[group_head[i]+j][0] = d2_temp[group_head[i]+j][0] = fabs(drand48());
        x1[group_head[i]+j][0] = x1_temp[group_head[i]+j][0] = drand48();
	for(l = 0; l < 5; l++)
	  param[group_head[i]+j][l] = param_temp[group_head[i]+j][l] = 0.0;
        y1[group_head[i]+j] = drand48();
      }
    }

    // batched
    ts = getTime();
    cblas_drotmg_batch(d1, d2, x1, y1, param, group_count, group_size);
    te = getTime();
    printf("batched= %e [s],", te - ts);
  
    // serial
    ts = getTime();
    for(i = 0; i < group_count; i++){
      for(j = 0; j < group_size[i]; j++){
        cblas_drotmg(d1_temp[group_head[i]+j], d2_temp[group_head[i]+j], x1_temp[group_head[i]+j], y1[group_head[i]+j], param_temp[group_head[i]+j]);
      }
    }
    te = getTime();
    printf("serial= %e [s],", te - ts);

    max_error = 0.0;
    for(i = 0; i < group_count; i++){
      for(j = 0; j < group_size[i]; j++){
        error = (d1_temp[group_head[i]+j][0] - d1[group_head[i]+j][0]);
        if(max_error < error)
          max_error = error;
        error = (d2_temp[group_head[i]+j][0] - d2[group_head[i]+j][0]);
        if(max_error < error)
          max_error = error;
        error = (x1_temp[group_head[i]+j][0] - x1[group_head[i]+j][0]);
        if(max_error < error)
          max_error = error;
	for(l = 0; l < 5; l++){
	  error = (param_temp[group_head[i]+j][l] - param[group_head[i]+j][l]);
	  if(max_error < error)
	    max_error = error;
	}
      }
    }
    printf("max_error= %e\n", max_error);
    
    for(i = 0; i < group_count; i++){
      for(j = 0; j < group_size[i]; j++){
        free(d1[group_head[i]+j]);
        free(d2[group_head[i]+j]);
        free(x1[group_head[i]+j]);
        free(param[group_head[i]+j]);
        free(d1_temp[group_head[i]+j]);
        free(d2_temp[group_head[i]+j]);
        free(x1_temp[group_head[i]+j]);
        free(param_temp[group_head[i]+j]);
      }
    }
    
    free(d1);
    free(d2);
    free(x1);
    free(param);
    free(d1_temp);
    free(d2_temp);
    free(x1_temp);
    free(param_temp);
    free(y1);
    
  }
  free(group_size);
  free(group_head);
  
}
