#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include <sys/time.h>

#include "batched_blas.h"
#include "batched_blas_test_common.h"

#define typ float

static double getTime(){
  struct timeval t;
  gettimeofday(&t,NULL);
  return t.tv_sec + (double) t.tv_usec*1e-6;
}

int main(int argc, char *argv[])
{
  int i,j,l;
  int nsize,gsize,group_count,*group_size,*group_head;
  CBLAS_LAYOUT layout;
  CBLAS_SIDE *side;
  CBLAS_UPLO *uplo;
  
  int *m,*n,*lda,*ldb,*ldc;
  typ *alpha,*beta;
  typ **a,**b;
  typ **c,**c_temp;
  double ts,te;
  double error,max_error;
  int try_number;
  int total_batch_count;
  int max_nsize;
  int a_size,b_size,c_size;
  int i_try;
  
  if(argc < 5){
    printf("usage : ./(load module) <try_number> <group_count> <group_size (random base) > <n (random base)>\n");
    exit(1);
  }

  try_number = atoi(argv[1]);
  group_count = atoi(argv[2]);
  gsize = atoi(argv[3]);
  nsize = atoi(argv[4]);
  
  printf("name= %s, try_number= %d, group_count= %d, group_size= %d, nsize= %d\n", argv[0], try_number, group_count, gsize, nsize);

  srand48(123L);

  group_size = (int *)malloc(sizeof(int) * group_count);
  group_head = (int *)malloc(sizeof(int) * group_count);
  side = malloc(sizeof(CBLAS_SIDE) * group_count);
  uplo = malloc(sizeof(CBLAS_UPLO) * group_count);
  m = (int *)malloc(sizeof(int) * group_count);
  n = (int *)malloc(sizeof(int) * group_count);
  lda = (int *)malloc(sizeof(int) * group_count);
  ldb = (int *)malloc(sizeof(int) * group_count);
  ldc = (int *)malloc(sizeof(int) * group_count);
  alpha = (typ *)malloc(sizeof(typ) * group_count);
  beta = (typ *)malloc(sizeof(typ) * group_count);

  for(i_try = 0; i_try < try_number; i_try++){
    // set group size
    total_batch_count = 0;
    for(i = 0; i < group_count; i++){
      group_size[i] = random_int((int)((1.0-VAL_RANGE)*gsize),gsize);
      total_batch_count += group_size[i];
    }
    // set group head
    group_head[0] = 0;
    for(i = 1; i < group_count; i++){
      group_head[i] = group_head[i - 1] + group_size[i - 1];
    }

    a = (typ **)malloc(sizeof(typ *) * total_batch_count);
    b = (typ **)malloc(sizeof(typ *) * total_batch_count);
    c = (typ **)malloc(sizeof(typ *) * total_batch_count);
    c_temp = (typ **)malloc(sizeof(typ *) * total_batch_count);
  
    // set parameter and value
    layout = r_layout_();
    for(i = 0; i < group_count; i++){
      side[i] = r_side_();
      uplo[i] = r_uplo_();
      m[i] = random_int((int)((1.0-VAL_RANGE)*nsize),nsize);
      n[i] = random_int((int)((1.0-VAL_RANGE)*nsize),nsize);
      max_nsize = MAX_2(m[i],n[i]);
      lda[i] = random_int(max_nsize, (int)(max_nsize*(1.0+VAL_RANGE)));
      ldb[i] = random_int(max_nsize, (int)(max_nsize*(1.0+VAL_RANGE)));
      ldc[i] = random_int(max_nsize, (int)(max_nsize*(1.0+VAL_RANGE)));
      alpha[i] = drand48();
      beta[i] = drand48();
      for(j = 0; j < group_size[i]; j++){
        if(side[i] == CblasLeft)
          a_size = lda[i] * m[i];
        else
          a_size = lda[i] * n[i];
        if(layout == CblasColMajor)
          b_size = ldb[i] * n[i];
        else
          b_size = ldb[i] * m[i];
        if(layout == CblasColMajor)
          c_size = ldc[i] * n[i];
        else
          c_size = ldc[i] * m[i];
        a[group_head[i]+j] = (typ *)malloc(sizeof(typ) * a_size);
        b[group_head[i]+j] = (typ *)malloc(sizeof(typ) * b_size);
        c[group_head[i]+j] = (typ *)malloc(sizeof(typ) * c_size);
        c_temp[group_head[i]+j] = (typ *)malloc(sizeof(typ) * c_size);
        for(l = 0; l < a_size; l++){
          a[group_head[i]+j][l] = drand48();
        }
        for(l = 0; l < b_size; l++){
          b[group_head[i]+j][l] = drand48();
        }
        for(l = 0; l < c_size; l++){
          c_temp[group_head[i]+j][l] = c[group_head[i]+j][l] = drand48();
        }
      }
    }
  
    // batched
    ts = getTime();
    cblas_ssymm_batch(layout, side, uplo, m, n, alpha, (const typ **)a, lda, (const typ **)b, ldb, beta, (typ **)c, ldc, group_count, group_size);
    te = getTime();
    printf("batched= %e [s],", te - ts);

    // serial
    ts = getTime();
    for(i = 0; i < group_count; i++){
      for(j = 0; j < group_size[i]; j++){
        cblas_ssymm(layout, side[i], uplo[i], m[i], n[i], alpha[i], a[group_head[i]+j], lda[i],
          b[group_head[i]+j], ldb[i], beta[i], c_temp[group_head[i]+j], ldc[i]);
      }
    }
    te = getTime();
    printf("serial= %e [s],", te - ts);
    // check
    max_error = 0.0;

    for(i = 0; i < group_count; i++){
      if(layout == CblasColMajor)
        c_size = ldc[i] * n[i];
      else
        c_size = ldc[i] * m[i];
      for(j = 0; j < group_size[i]; j++){
        for(l = 0; l < c_size; l++){
          error = fabs(c_temp[group_head[i]+j][l]-c[group_head[i]+j][l]);
          if(error > max_error)
            max_error = error;
        }
      }
    }

    printf("max_error= %e\n", max_error);
  
    for(i = 0; i < group_count; i++){
      for(j = 0; j < group_size[i]; j++){
        free(a[group_head[i]+j]);
        free(b[group_head[i]+j]);
        free(c[group_head[i]+j]);
        free(c_temp[group_head[i]+j]);
      }
    }
    free(a);
    free(b);
    free(c);
    free(c_temp);
  }
  
  free(group_size);
  free(group_head);
  free(side);
  free(uplo);
  free(m);
  free(n);
  free(lda);
  free(ldb);
  free(ldc);
  free(alpha);
  free(beta);
  
}

